function Param=GetOptions(trialname)

% function Param=GetOptions(trialname)
%
% get options from trialname
% called by run_ffnn.m

% Name and number of experiment as string
Param.trialname = trialname;

if findstr(Param.trialname, '_clean_')
    Param.datatype = 'clean'; % noisy or clean zifkom
elseif findstr(Param.trialname, '_noisy_')
    Param.datatype = 'noisy';
elseif findstr(Param.trialname, '_small_')
    Param.datatype = 'small';
elseif findstr(Param.trialname, '_nsmall_')
    Param.datatype = 'nsmall';
end

if findstr(Param.trialname, 'zifkom_')
    
    Param.classnum = 10; % Number of classes 
    Param.workdir = '.'; % dir of this script
    Param.datadir = './Corpora/zifkom/melspec'; % dir of input data

    % Dir containing train data (as primary feature vectors)
    Param.TRAINPrimeFeatDir =  [Param.datadir '/train/' Param.datatype];
    Param.alltrainnum  = 0; % only for TIMIT, but var needs to be defined
    Param.allcvnum     = 0;   
    
    if findstr(Param.trialname, '_small_')        
        Param.classnum = 2;         
    end
elseif findstr(Param.trialname, 'OLLO_')
    
    Param.classnum = 10; % Number of classes 
    Param.workdir = '.'; % dir of this script
    Param.datadir = './Corpora/OLLO/melspec'; % dir of input data

    % Dir containing train data (as primary feature vectors)
    Param.TRAINPrimeFeatDir =  [Param.datadir '/train/' Param.datatype];
    Param.alltrainnum  = 0; % only for TIMIT, but var needs to be defined
    Param.allcvnum     = 0;   
    
    if findstr(Param.trialname, '_small_')        
        Param.classnum = 2;         
    end

    
elseif findstr(Param.trialname,'TIdigits_')
    
    Param.classnum = 11; % Number of classes 
    Param.workdir = '.'; % dir of this script
    Param.datadir = './Corpora/TIdigits_single/melspec'; % dir of input data
    Param.workdir = '.';
    % Param.datadir = './Corpora/IR/melspec/TIdigits_single';

    % Dir containing train data (as primary feature vectors)
    Param.TRAINPrimeFeatDir =  [Param.datadir '/train/' Param.datatype];
    Param.alltrainnum  = 0; % only for TIMIT, but var needs to be defined
    Param.allcvnum     = 0; 
    Param
    
elseif findstr(Param.trialname,'TIMIT_')
    
    Param.workdir = '.'; % dir of this script
    Param.datadir = './Corpora/AN_TIMIT/melspec'; % dir of input data

    Param.alltrainnum  = 4500; % number of train sentences (=files) in the corpus (TIMIT) (first part of list)
    Param.allcvnum     = 540;  % number of cv sentences (=files) in the corpus (TIMIT) (last part of list)
    
    % Dir containing train data (as primary feature vectors)
    Param.TRAINPrimeFeatDir =  [Param.datadir '/'  Param.datatype];
    
    Param.trainfilestart = 1;
    if findstr(Param.trialname, 'Files')
        pos_feat = findstr(Param.trialname, 'Files');
        pos__ = findstr(Param.trialname, '_');
        Param.trainfilenum = str2num(Param.trialname(pos__(max(find((pos__ - pos_feat) < 0))) + 1 : pos_feat - 1));
    else
        error('Number of trainfiles needed!');
    end
    
    if findstr(Param.trialname,'_ICSI56_')
        %Param.Labelmode = 'ICSI56';
        Param.classnum = 56; % Number of classes 
    elseif findstr(Param.trialname,'Voicing3_')
        %Param.Labelmode = 'ICSI56';
        Param.classnum = 3; % Number of classes 
    elseif findstr(Param.trialname,'Manner6_')
        Param.classnum = 6; % Number of classes 
    elseif findstr(Param.trialname,'Place9_')
        Param.classnum = 9; % Number of classes 
    elseif findstr(Param.trialname,'BroadDupont10_')
        Param.classnum = 10; % Number of classes 
    elseif findstr(Param.trialname,'BroadPlaceDupont9_')
        Param.classnum = 9; % Number of classes 
    elseif findstr(Param.trialname,'diphthongs6_')
        Param.classnum = 6; % Number of classes 
    elseif findstr(Param.trialname,'vowels8_')
        Param.classnum = 8; % Number of classes 
    elseif findstr(Param.trialname,'stops14_')
        Param.classnum = 14; % Number of classes 
    elseif findstr(Param.trialname,'nasal5_')
        Param.classnum = 5; % Number of classes 
    elseif findstr(Param.trialname,'fricative10_')
        Param.classnum = 10; % Number of classes 
    else
        error('labelmode not supported')
    end
    
else
    error('only zifkom, OLLO, TIdigits and TIMIT supported!');
end

if findstr(Param.trialname, '_fdim23_')
    Param.dim = 23; % Dimension of primary feature vectors (in freq direction)       
else
    error('Dimension of primary feature matrix not specified!!')
end

% set all flags to zero
Param.mag_flag  = 0;        % magnitude of complex Gabor as feature
Param.real_flag = 0;        % real part of complex Gabor as feature
Param.imag_flag = 0;        % imag part of complex Gabor as feature

if findstr(Param.trialname, '_abs_')
    Param.mag_flag = 1; 
end
if findstr(Param.trialname, '_real_')
    Param.real_flag = 1; 
end
if findstr(Param.trialname, '_imag_')
    Param.imag_flag = 1; 
end

if findstr(Param.trialname, 'Feat')
    pos_feat = findstr(Param.trialname, 'Feat');
    pos__ = findstr(Param.trialname, '_');
    Param.Allfeaturenum = str2num(Param.trialname(pos__(max(find((pos__ - pos_feat) < 0))) + 1 : pos_feat - 1));    
else
    error('Number of features per BoostIteration needed!');
end

if findstr(Param.trialname, 'Iter')
    pos_iter = findstr(Param.trialname, 'Iter');
    pos__ = findstr(Param.trialname, '_');
    Param.MaxIteration = str2num(Param.trialname(pos__(max(find((pos__ - pos_iter) < 0))) + 1 : pos_iter - 1));
else
    error('Number of iterations needed!');
end

if findstr(Param.trialname, 'BoostIt')
    pos_iter = findstr(Param.trialname, 'BoostIt');
    pos__ = findstr(Param.trialname, '_');
    Param.BoostIt = str2num(Param.trialname(pos__(max(find((pos__ - pos_iter) < 0))) + 1 : pos_iter - 1));
else
    error('Number of Boost Iterations needed!');
end

if findstr(Param.trialname, 'FmodTmin')
    pos_iter = findstr(Param.trialname, 'FmodTmin');
    pos__ = findstr(Param.trialname, '_');
    Param.FmodTmin = str2num(Param.trialname(pos__(max(find((pos__ - pos_iter) < 0))) + 1 : pos_iter - 1));
    fprintf('FmodTmin set to %i Hz\n',Param.FmodTmin*100);
else
    Param.FmodTmin = 2; %Hz
    fprintf('FmodTmin set to default %i Hz\n',Param.FmodTmin);
end

if findstr(Param.trialname, 'FmodTmax')
    pos_iter = findstr(Param.trialname, 'FmodTmax');
    pos__ = findstr(Param.trialname, '_');
    Param.FmodTmax = str2num(Param.trialname(pos__(max(find((pos__ - pos_iter) < 0))) + 1 : pos_iter - 1))
    fprintf('FmodTmax set to %i Hz\n',Param.FmodTmax);
else
    Param.FmodTmax = 50; %Hz
    fprintf('FmodTmax set to default %i Hz\n',Param.FmodTmax);
end

if findstr(Param.trialname, 'Env')
    pos_iter = findstr(Param.trialname, 'Env');
    pos__ = findstr(Param.trialname, '_');
    Param.EnvType = lower(Param.trialname(pos__(max(find((pos__ - pos_iter) < 0))) + 1 : pos_iter - 1));
    disp(['EnvType set to ' Param.EnvType '.']);
else
    error('Type of Envelope needed. Try HannEnv or GausEnv in parameter string');
end

if isempty(findstr(Param.EnvType, 'hann')) & isempty(findstr(Param.EnvType, 'gaus'))
  disp(['Type of envelope is set to ' Param.EnvType '.']);
  error('Type of envelope must be either Hann (Hanning envelope) or Gaus (Gaussian envelope)');
end

if Param.MaxIteration > 100
    Param.discardnumFlood = 2;
else
    Param.discardnumFlood = 3;
end

%%-----------------------------------------------------------------------------
%%
%%   Copyright (C) 2000-2004   
%%   Medizinische Physik,
%%   Universitaet Oldenburg, Germany
%%   All rights reserved. 
%%   http://www.physik.uni-oldenburg.de/docs/medi
%%
%%   Permission to use, copy, and distribute this software/file and its
%%   documentation for any purpose without permission by UNIVERSITAET OLDENBURG
%%   is not granted.
%%   
%%   Permission to use this software for purely research (excluding weapons 
%%   research) or educational purposes is granted, with the exception that 
%%   modified versions of the code may not be redistributed unless permission 
%%   has been obtained separately from UNIVERSITAET OLDENBURG.
%%
%%   Permission to use this software for weapons research or applications is 
%%   not granted.
%%
%%   No commercial exploitation of this software is permitted unless permission 
%%   has been obtained separately from UNIVERSITAET OLDENBURG. 
%%
%%   This software is provided "as is" without expressed or implied warranty.
%%
%%   Author:    Michael Kleinschmidt
%%   Co-Author: Bernd Meyer 
%%
%%   Please contact Bernd Meyer (bernd.meyer@uni-oldenburg.de) for 
%%   questions regarding this release.
%%----------------------------------------------------------------------------- 
