function calc_melspec_many
% -------------------------------------------------------------------------
% reads, processes and writes files from / to directory structure         %
% works with Linux and Windows systems                                    %
% (c) Bernd Meyer University Oldenburg, Feb 2005                          %
% -------------------------------------------------------------------------

% -------------------------------------
% --- start parameter configuration ---
% -------------------------------------

% working directory (where m-files and filelists are stored)
sWorkDir  = strrep(pwd,'\','/');

% define input directory
sInputDir = ['d:/docs/testin'];
% define output directory
sOutputDir = ['d:/docs/testout'];

% which files are to be processed / 
sInFileExt  = '.wav';
sOutFileExt = '.htk';

% filelist in ASCII format
sFileList = [sWorkDir '/' 'filelist.txt'];

% should the script output be logged?
iUseDiary = 0;
diaryfile = [sWorkDir '/diary.txt']; 

% -----------------------------------
% --- end parameter configuration ---
% -----------------------------------

if iUseDiary
   % path to diary file   
   diary(diaryfile); diary on;
end % of if

sInputDir  = strrep(sInputDir,'\','/');
sOutputDir = strrep(sOutputDir,'\','/');

disp(['Generating list from all files in ' sInputDir ' matching *' sInFileExt]);
Data.InFileName = getfilenames(sInputDir, ['*' sInFileExt]);

% reformat filenames / determine output filename / log filelist
disp(['Logging list of files in ' sFileList]);
fid_filelist = fopen(sFileList,'w');
for i = 1:length(Data.InFileName)
   Data.InFileName{i}  = strrep(Data.InFileName{i}, '\', '/');
   Data.InFileNoExt{i} = strrep(Data.InFileName{i},sInFileExt,'');
   Data.InDir{i}       = get_directory_only(Data.InFileName{i});
   Data.DirRelative{i} = strrep(Data.InDir{i}, sInputDir, '');
   Data.NameOnly{i}    = get_filename_only(Data.InFileNoExt{i});
   Data.OutFileName{i} = [sOutputDir ...
      Data.DirRelative{i} Data.NameOnly{i} sOutFileExt];
   fprintf(fid_filelist,'%s\n',Data.InFileName{i});
end % of while
fclose(fid_filelist);

display = 0;
iStartNumber = 1;

for iFileNumber = iStartNumber:length(Data.InFileName)

   sOutputDisplay = Data.InFileName{iFileNumber};
   
   % -------------------------
   % start processing block  %
   % -------------------------

   % read input files
   [vInput,fs,nbits] = wavread([Data.InFileName{iFileNumber}]);
   
   % create output dir if it doesn't exist
   CreateDir(sOutputDir, Data.DirRelative{iFileNumber});
   plotflag = 0;
   [melspec] = calc_melspec(vInput, fs, plotflag);
   header.nSamples = size(melspec,2); % number of frames
   header.sampKind = 8198; % std for gabor features
   header.sampPeriod = 100000; % sample period in 100ns units
   header.sampSize = 4*size(melspec,1); % number of bytes per feature vec
   % write signal to file   
   write_htk_with_header(melspec,header,Data.OutFileName{iFileNumber},0);
   
   % -------------------------
   % end processing block    %
   % -------------------------

   sOutputDisplay = [sOutputDisplay ' -> ' Data.OutFileName{iFileNumber}];
   Data.sOutputDisplay{iFileNumber} = sOutputDisplay;
   disp(sOutputDisplay);

end % of for

fclose('all');

disp(['Finished. Saving file information in ' sWorkDir '/filedata.mat (cellarray Data)']);
save([sWorkDir '/filedata.mat'],'Data' );

if iUseDiary
   diary off;
end % of if
%--------------------------------------------------------------------------
function [out] = get_filename_only(in)
slashes = find(in == '/');
out = in(slashes(length(slashes))+1:length(in));

%--------------------------------------------------------------------------
function [out] = get_directory_only(in)
slashes = find(in == '/');
out = in(1:slashes(length(slashes)));

%--------------------------------------------------------------------------
function CreateDir(basedir, dirname)
% Bernd Meyer, University of Oldenburg, Medical Physics Section

iVerboseFlag = 0;
basedir = strrep(basedir,'\','/');
dirname = strrep(dirname,'\','/');

% for each file: check if the destination directory exists, if not, create it
fulldir = [basedir '/' dirname];
while fulldir(end) == '/'
   fulldir = fulldir(1:end-1);
end

if fulldir(1) == '/'
   absdir = fulldir(1);
   reldir = fulldir(2:end);
elseif fulldir([2 3]) == [':/']
   absdir = fulldir(1:3);
   reldir = fulldir(4:end);
else
   absdir = '.';
   reldir = fulldir;
end

if ~exist(fulldir)
   if iVerboseFlag
      disp(['Trying to create ' fulldir]);
   end
   [dummy, dummy2, dummy3] = mkdir(absdir,reldir);
else
   if iVerboseFlag
      disp(['dir creation of ' fulldir ' not necessary']);
   end
end

%--------------------------------------------------------------------------
function filenames = getfilenames(root,refiles)
%---Returns a cell array of all files matching the wildcard expression
%---"refiles" beginning in the root folder "root". Includes subdirectories
%---Example: mfiles = getfilenames('c:\','*.m') will return all .m files
%---on the c drive to the cell array "mfiles". 

%---Note: Never tested on a Unix Box. 

%---Joe Burgel, General Motors, 8/2002

MyPwd = cd; %---We will come back here when we're done
filesep = '/'; 
filenames = {};

try, 
    cd(root);
catch,
    return;
end

AllFiles = dir('*'); %--Everything in this folder
MyFiles = dir(refiles); %--The files we need in this folder

%---Build a list of all the files matching the regular expression in this folder
for k=1:length(MyFiles)
    filenames{k} = [cd filesep MyFiles(k).name];
end

%---Do a recursive call of this function for every sub directory of this folder
SkipFolder1 = [cd filesep '.'];
SkipFolder2 = [cd filesep '..'];
for k=1:length(AllFiles)
    if AllFiles(k).isdir
        ThisFolder = [cd filesep AllFiles(k).name];
        if ~(strcmp(ThisFolder,SkipFolder1)|strcmp(ThisFolder,SkipFolder2))
            filenames = [filenames  ...
                    getfilenames(ThisFolder,refiles)];
        end
    end
    
end

%---Return to the present directory
cd(MyPwd);

%--------------------------------------------------------------------------
function write_htk_with_header(data,header,outfile,byteswap)
% function write_htk_with_header(data,header,file,byteswap)
% writes HTKfile with header 
% Michael Kleinschmidt, MEDI, Oct 2002

%open file for write
if byteswap == 0
  fid = fopen(outfile,'w');
else
  fid = fopen(outfile,'w','b');
end

% write htk header
write_htk_header(fid,header)

% write data
count = fwrite(fid,data,'float');

%close file
fclose(fid);

%--------------------------------------------------------------------------
function write_htk_header(fid,header) 

% number of samples in file
count = fwrite(fid,header.nSamples,'int');
% sample period in 100ns units 
count = fwrite(fid,header.sampPeriod,'int');
% number of bytes per sample
count = fwrite(fid,header.sampSize,'short');
% a code indicating the sample kind
% 0 = waveform
% 8198 std. for gabor features
count = fwrite(fid,header.sampKind,'short');

%%-----------------------------------------------------------------------------
%%
%%   Copyright (C) 2000-2004   
%%   Medizinische Physik,
%%   Universitaet Oldenburg, Germany
%%   All rights reserved. 
%%   http://www.physik.uni-oldenburg.de/docs/medi
%%
%%   Permission to use, copy, and distribute this software/file and its
%%   documentation for any purpose without permission by UNIVERSITAET OLDENBURG
%%   is not granted.
%%   
%%   Permission to use this software for purely research (excluding weapons 
%%   research) or educational purposes is granted, with the exception that 
%%   modified versions of the code may not be redistributed unless permission 
%%   has been obtained separately from UNIVERSITAET OLDENBURG.
%%
%%   Permission to use this software for weapons research or applications is 
%%   not granted.
%%
%%   No commercial exploitation of this software is permitted unless permission 
%%   has been obtained separately from UNIVERSITAET OLDENBURG. 
%%
%%   This software is provided "as is" without expressed or implied warranty.
%%
%%   Author:    Michael Kleinschmidt
%%   Co-Author: Bernd Meyer 
%%
%%   Please contact Bernd Meyer (bernd.meyer@uni-oldenburg.de) for 
%%   questions regarding this release.
%%----------------------------------------------------------------------------- 