function Param=limits(Param)

% Function for generating parameter ranges for feature prototypes

if findstr(Param.trialname,'ComplexGabor_')
   
  % 'ComplexGabor_'       : Complex Gabor filter  
  
  % set dim
  Param.limits.dim = Param.dim;
  
  % set props for types
  if findstr(Param.trialname,'_s_only_')
	Param.limits.Pspectral = 1;
	Param.limits.Ptemporal = 0;
	Param.limits.PSTup = 0;
	Param.limits.PSTdown = 0;
  elseif findstr(Param.trialname,'_t_only_')
	Param.limits.Pspectral = 0;
	Param.limits.Ptemporal = 1;
	Param.limits.PSTup = 0;
	Param.limits.PSTdown = 0;
  elseif findstr(Param.trialname,'_sandt_only_')
	Param.limits.Pspectral = 0.5;
	Param.limits.Ptemporal = 0.5;
	Param.limits.PSTup = 0;
	Param.limits.PSTdown = 0;
  elseif findstr(Param.trialname,'_s_and_t_and_ST_')
	Param.limits.Pspectral = 0.25;
	Param.limits.Ptemporal = 0.25;
	Param.limits.PSTup = 0.25;
	Param.limits.PSTdown = 0.25;
  elseif findstr(Param.trialname,'_ST_only')
	Param.limits.Pspectral = 0;
	Param.limits.Ptemporal = 0;
	Param.limits.PSTup = 0.5;
	Param.limits.PSTdown = 0.5;
 elseif findstr(Param.trialname,'_STup_only')
         Param.limits.Pspectral = 0;
	 Param.limits.Ptemporal = 0;
	 Param.limits.PSTup = 1;
	 Param.limits.PSTdown = 0;
 elseif findstr(Param.trialname,'_STdown_only')
          Param.limits.Pspectral = 0;
          Param.limits.Ptemporal = 0;
          Param.limits.PSTup = 0;
          Param.limits.PSTdown = 1;
else 
	error('trialname does not indicate types of Gabor features used')
  end
  
  Param.limits.Props(1)=Param.limits.Pspectral;
  Param.limits.Props(2)=Param.limits.Ptemporal+Param.limits.Props(1);
  Param.limits.Props(3)=Param.limits.PSTup+Param.limits.Props(2);
  Param.limits.Props(4)=Param.limits.PSTdown+Param.limits.Props(3);
  if Param.limits.Props(4) ~= 1 
	error ('props have to sum up to 1')
  end
  
  % set ranges for modulation frequencies
  Param.limits.FmodFmax = 0.5; % cycl./channel
  Param.limits.FmodFmin = 1/Param.dim; % cycl./channel
  Param.limits.TmodFmax = Param.FmodTmax/100; %50/100; % 100 Hz
  Param.limits.TmodFmin = Param.FmodTmin/100; % 2/100;% 100Hz
  
  % set ranges for sigmas if modF = 0 (for spectral and temporal features),
  % otherwise sigma=1/modF/2;
  Param.limits.Fsigmamin = 0.5; % channels
  Param.limits.Fsigmamax = Param.dim/8; % channels
  Param.limits.Tsigmamin = 0.5; % 10ms
  Param.limits.Tsigmamax = 3; % 10ms
  
  % set range for support
  Param.limits.Fcutmin = 1.5; % multiples of sigma (1)
  Param.limits.Fcutmax = 1.5; % multiples of sigma (2)
  Param.limits.Tcutmin = 1.5; % multiples of sigma (1)
  Param.limits.Tcutmax = 1.5; % multiples of sigma (2)
  
  % set parameters for hanning envelope
  % set this depending on omega_f and omega_t, so 
  % that the same number of oscillations within envelope is used.
  % when omega_f is 0, HannFWidth becomes a free parameter and these values are used:
  Param.limits.HannFWidthMin = 0.5; % channels
  Param.limits.HannFWidthMax = Param.dim/8; % channels, max. extension in freq.: 7 channels (whole feature)
  Param.limits.HannTWidthMin = 0.5; % 10 ms
  Param.limits.HannTWidthMax = 3;   % 10 ms
  
  % set different modes
  Param.limits.modes = {};
  if Param.mag_flag
	Param.limits.modes{length(Param.limits.modes)+1}={'mag'};
  end
  if Param.real_flag
	Param.limits.modes{length(Param.limits.modes)+1}={'real'};
  end
  if Param.imag_flag
	Param.limits.modes{length(Param.limits.modes)+1}={'imag'};
  end
  
  
   % Set limit structure of contraints
   Param.limits.dim = Param.dim;     % number of frequency channels
   
   % set types of response activation (has to be set for corpora which
   % are not phoneme-labeled
   if findstr(Param.trialname,'zifkom_')
	 Param.limits.activation = {'abs' 'greater_zero' 'less_zero'};
   elseif findstr(Param.trialname,'TIdigits_')
	 Param.limits.activation = {'abs' 'greater_zero' 'less_zero'};
   elseif findstr(Param.trialname,'OLLO_')
         Param.limits.activation = {'abs' 'greater_zero' 'less_zero'};
   else
	 Param.limits.activation = {'no'}; 
   end
end

%%-----------------------------------------------------------------------------
%%
%%   Copyright (C) 2000-2004   
%%   Medizinische Physik,
%%   Universitaet Oldenburg, Germany
%%   All rights reserved. 
%%   http://www.physik.uni-oldenburg.de/docs/medi
%%
%%   Permission to use, copy, and distribute this software/file and its
%%   documentation for any purpose without permission by UNIVERSITAET OLDENBURG
%%   is not granted.
%%   
%%   Permission to use this software for purely research (excluding weapons 
%%   research) or educational purposes is granted, with the exception that 
%%   modified versions of the code may not be redistributed unless permission 
%%   has been obtained separately from UNIVERSITAET OLDENBURG.
%%
%%   Permission to use this software for weapons research or applications is 
%%   not granted.
%%
%%   No commercial exploitation of this software is permitted unless permission 
%%   has been obtained separately from UNIVERSITAET OLDENBURG. 
%%
%%   This software is provided "as is" without expressed or implied warranty.
%%
%%   Author:    Michael Kleinschmidt
%%   Co-Author: Bernd Meyer 
%%
%%   Please contact Bernd Meyer (bernd.meyer@uni-oldenburg.de) for 
%%   questions regarding this release.
%%----------------------------------------------------------------------------- 
