function [sPrimary]=load_many_TIMIT(PrimeFeatDir,Param,startnum,num)

% function [sPrimary]=load_many_TIMIT(Param,startnum,num)
% 
% reads primary features from HTK format files and attaches the correct
% frame labels to it. information about using noisy/clean TIMIT directly
% implicates the labelfile, listfile and the subdirectory of the data.  
%
% IN:
% Param: structure containing (at least) the following subvariables:
%   - PrimeFeatDir : string containing root feature directory
%   - TIMITtype : 'clean' or 'noisy' (identical to subdir)
% startnum : position of first file to be read in listfile, starting with 1
% num :   number of files to be read 
%
% OUT:
% sPrimary: array of structure containing
%   - mIR : input feature matrix
%   - vLabels : label vector
%
% Michael Kleinschmidt, ICSI, Nov 2001

for k=1:num
  if ~mod(k,100)
    disp(['Loading file no. ' num2str(k) ' from ' num2str(num)]);
  end
  sPrimary(k)=load_TIMIT_with_label(PrimeFeatDir,Param.datatype,startnum+k-1,0);
  
% change labels for phonemes (grouping)
  if findstr(Param.trialname,'_ICSI56_')
	sPrimary(k).vLabels=sPrimary(k).vLabels+1;
  elseif findstr(Param.trialname,'_BroadDupont10_')
	sPrimary(k).vLabels=BroadLabel(sPrimary(k).vLabels);
  elseif findstr(Param.trialname,'_BroadPlaceDupont9_')
	sPrimary(k).vLabels=BroadPlaceLabel(sPrimary(k).vLabels);
  elseif findstr(Param.trialname,'_Manner6_')
	sPrimary(k).vLabels=AFLabel(sPrimary(k).vLabels,'MANNER');
  elseif findstr(Param.trialname,'_Place9_')
	sPrimary(k).vLabels=AFLabel(sPrimary(k).vLabels,'PLACE');
  elseif findstr(Param.trialname,'_Voicing3_')
	sPrimary(k).vLabels=AFLabel(sPrimary(k).vLabels,'VOICING');
  % change labels for selected phones (need Diphone in trialname for getting
  % rid of zeros later)
  elseif findstr(Param.trialname,'_phones-diphthongs6_')
	sPrimary(k).vLabels=SelectLabel(sPrimary(k).vLabels,'DIPHTHONGS-6');
  elseif findstr(Param.trialname,'_phones-vowels8_')
	sPrimary(k).vLabels=SelectLabel(sPrimary(k).vLabels,'VOWELS-8');
  elseif findstr(Param.trialname,'_phones-stops14_')
	sPrimary(k).vLabels=SelectLabel(sPrimary(k).vLabels,'STOPS-14');
  elseif findstr(Param.trialname,'_phones-nasal5_')
	sPrimary(k).vLabels=SelectLabel(sPrimary(k).vLabels,'NASAL-5');
  elseif findstr(Param.trialname,'_phones-fricative10_')
	sPrimary(k).vLabels=SelectLabel(sPrimary(k).vLabels,'FRICATIVE-10');
  % change labels for diphone (grouping and relocating)
  elseif findstr(Param.trialname,'AFManner-all') % new version of place of articulation features
	sPrimary(k).vLabels=NewAFLabel(sPrimary(k).vLabels,'AFManner-all');
	sPrimary(k).vLabels=DiphoneLabel(sPrimary(k).vLabels,Param);
  elseif findstr(Param.trialname,'AFManner-highallinone') % new version of place of articulation features
	sPrimary(k).vLabels=NewAFLabel(sPrimary(k).vLabels,'AFManner-highallinone');
	sPrimary(k).vLabels=DiphoneLabel(sPrimary(k).vLabels,Param);
  elseif findstr(Param.trialname,'AFManner-iy') % new version of place of articulation features
	sPrimary(k).vLabels=NewAFLabel(sPrimary(k).vLabels,'AFManner-iy');
	sPrimary(k).vLabels=DiphoneLabel(sPrimary(k).vLabels,Param);
  elseif findstr(Param.trialname,'AFPlace-allvowels') % new version of place of articulation features
	sPrimary(k).vLabels=NewAFLabel(sPrimary(k).vLabels,'AFPlace-allvowels');
	sPrimary(k).vLabels=DiphoneLabel(sPrimary(k).vLabels,Param);
  elseif findstr(Param.trialname,'AFPlace-highvowels') % new version of place of articulation features
	sPrimary(k).vLabels=NewAFLabel(sPrimary(k).vLabels,'AFPlace-highvowels');
	sPrimary(k).vLabels=DiphoneLabel(sPrimary(k).vLabels,Param);
  elseif findstr(Param.trialname,'AFPlace-iy') % new version of place of articulation features
	sPrimary(k).vLabels=NewAFLabel(sPrimary(k).vLabels,'AFPlace-iy');
	sPrimary(k).vLabels=DiphoneLabel(sPrimary(k).vLabels,Param);
  elseif findstr(Param.trialname,'AFPlace-ae') % new version of place of articulation features
	sPrimary(k).vLabels=NewAFLabel(sPrimary(k).vLabels,'AFPlace-ae');
	sPrimary(k).vLabels=DiphoneLabel(sPrimary(k).vLabels,Param);
  elseif findstr(Param.trialname,'AFPlace-ow') % new version of place of articulation features
	sPrimary(k).vLabels=NewAFLabel(sPrimary(k).vLabels,'AFPlace-ow');
	sPrimary(k).vLabels=DiphoneLabel(sPrimary(k).vLabels,Param);
  elseif findstr(Param.trialname,'AFPlace-Diphone64') % new version of place of articulation features
	sPrimary(k).vLabels=NewAFLabel(sPrimary(k).vLabels,'AFPlace');
	sPrimary(k).vLabels=DiphoneLabel(sPrimary(k).vLabels,Param);
  else % assume ICSI56
	disp('assuming ICSI56')
	sPrimary(k).vLabels=sPrimary(k).vLabels+1;
  end

end

return

%%-----------------------------------------------------------------------------
%%
%%   Copyright (C) 2000-2004   
%%   Medizinische Physik,
%%   Universitaet Oldenburg, Germany
%%   All rights reserved. 
%%   http://www.physik.uni-oldenburg.de/docs/medi
%%
%%   Permission to use, copy, and distribute this software/file and its
%%   documentation for any purpose without permission by UNIVERSITAET OLDENBURG
%%   is not granted.
%%   
%%   Permission to use this software for purely research (excluding weapons 
%%   research) or educational purposes is granted, with the exception that 
%%   modified versions of the code may not be redistributed unless permission 
%%   has been obtained separately from UNIVERSITAET OLDENBURG.
%%
%%   Permission to use this software for weapons research or applications is 
%%   not granted.
%%
%%   No commercial exploitation of this software is permitted unless permission 
%%   has been obtained separately from UNIVERSITAET OLDENBURG. 
%%
%%   This software is provided "as is" without expressed or implied warranty.
%%
%%   Author:    Michael Kleinschmidt
%%   Co-Author: Bernd Meyer 
%%
%%   Please contact Bernd Meyer (bernd.meyer@uni-oldenburg.de) for 
%%   questions regarding this release.
%%----------------------------------------------------------------------------- 