function plot_optimal_set_ordered(filename, num)

% IN:
% filename : name of file containing optimal features/prototypes in Test.sSelectSetSort structure
% [num]: optional, number of features to be plotted (starting with highest relevance)
% or vector containing the numbers of features to be plotted
%
% Examples: 
% plot_optimal_set_ordered(filename) plots all 2-D modulation filter functions
% plot_optimal_set_ordered(filename, 30) plots the 30 most important Gabor functions
% plot_optimal_set_ordered(filename, [4 5 6 20]) plots Gabor functions with
%         indices according to 2nd argument vector
% 
% Michael Kleinschmidt, ICSI, Feb 2002
% Bernd Meyer, Oldenburg, Aug 2004

if nargin < 1
  disp('not enough input arguments');
  disp('maybe you want to try one of those files (without extension) as first parameter: ');
  ls ./testdir/*Length.mat
  error('not enough input arguments');
end

eval(['load ./testdir/' filename '.mat'])

% Define indexvector
if nargin==1
  vec=[length(Test.sSelectSetSort):-1:1];
else
  if (length(num) == 1)
		% reversed order
		vec=[length(Test.sSelectSetSort):-1:length(Test.sSelectSetSort)-num+1];
		if num > length(Test.sSelectSetSort)
	  	error('num to large!')
		end
  else
    vec = num;
  end
end

H=floor(sqrt(length(vec)))+2;
V=ceil(length(vec)/H);
tvec=[-50:50];
fvec=[1:Param.dim];

% Generate figure with subplots
[sh, fignum] = gensubpl('lt', H, V, 0.8, 0.8, 't [s]', 'Channel');

% generate bins for statistics
allstat=zeros(4, 1); 
halfstat=zeros(4, 1);
Fcenter_hist = zeros(1,23);

for k=1:length(vec)
  
  
  subplot(sh(k))
  
  support = zeros(23,101);
  % center at this freq. channel
  Fcenter = Test.sSelectSetSort(vec(k)).prototype.Fcenter;
  Fcenter_hist(Fcenter) = Fcenter_hist(Fcenter) + 1;
    
  size_f = size(abs(Test.sSelectSetSort(vec(k)).prototype.Yinv),1);
  size_t = size(abs(Test.sSelectSetSort(vec(k)).prototype.Yinv),2);
    
  diff_f = 23 - Fcenter;
  diff_t = round((101 - size_t)/2);

  if strcmp(Test.sSelectSetSort(vec(k)).prototype.mode, 'mag')
 	  matri_small=real(Test.sSelectSetSort(vec(k)).prototype.Yinv)+imag(Test.sSelectSetSort(vec(k)).prototype.Yinv);
    offset(vec(k)) = mean(mean(matri_small));    
  elseif isreal(Test.sSelectSetSort(vec(k)).prototype.Yinv)
    if strcmp(Test.sSelectSetSort(vec(k)).prototype.mode, 'real')
    	matri_small=(Test.sSelectSetSort(vec(k)).prototype.Yinv);
      offset(vec(k)) = mean(mean(matri_small));
    else
     	matri_small=(Test.sSelectSetSort(vec(k)).prototype.Yinv);
      offset(vec(k)) = mean(mean(matri_small));
    end
  else
    error('Yinv should be either of type mag or contain only real values');
  end

matri_small = matri_small - matri_small(end,1);

  support(1+diff_f:size_f+diff_f,1+diff_t:size_t+diff_t) = matri_small;
  matri = support;

maxi=max(max(abs(matri)));

imagesc(tvec/100, fvec, matri, [-maxi maxi])
  axis xy
  ati=sprintf('#%i F_f=%3.2f F_t=%3.1fHz %s', k, Test.sSelectSetSort(vec(k)).prototype.FmodF, 100*Test.sSelectSetSort(vec(k)).prototype.TmodF, char(Test.sSelectSetSort(vec(k)).prototype.mode));
  ta=title(ati);
  set(ta, 'FontSize', 6)
  
  if (Test.sSelectSetSort(vec(k)).prototype.TmodF ==0)
	allstat(1)=allstat(1)+1;
  elseif (Test.sSelectSetSort(vec(k)).prototype.FmodF ==0)
	allstat(2)=allstat(2)+1;
  elseif (Test.sSelectSetSort(vec(k)).prototype.TmodF > 0)
	allstat(3)=allstat(3)+1;
  else
	allstat(4)=allstat(4)+1;
  end
  if k<=length(vec)/2
	if (Test.sSelectSetSort(vec(k)).prototype.TmodF ==0)
	  halfstat(1)=halfstat(1)+1;
	elseif (Test.sSelectSetSort(vec(k)).prototype.FmodF ==0)
	  halfstat(2)=halfstat(2)+1;
	elseif (Test.sSelectSetSort(vec(k)).prototype.TmodF > 0)
	  halfstat(3)=halfstat(3)+1;
	else
	  halfstat(4)=halfstat(4)+1;
	end
  end
end

clear_inner_ticklabels(sh)

subplot(sh(k))
wo=H*V-length(vec);
text(-1.1*(H-wo-1), -3-V, ['ZIFKOM ' strrep(filename, '_', '-') '  ORDERED (higher number : higher relevance)'])

all=allstat';
half=halfstat';

%---------------------------------------------------------------------
function [sh,fignum] = gensubpl(mode,H,V,hf,vf,hin,vin,hout,vout,htl,vtl)
%
% gensubpl.m - generates a subplot with or without outer axis,
%              returns a vector or matrix of subhandles sh to the individual subplots
%
% usage   : sh = gensubpl(mode,H,V,hf,vf,hin,vin,hout,vout,htl,vtl);
% examples: sh = gensubpl('ot',3,4,0.95,0.8,'t [ms]','U [uV]','ITD [ms]','ILD [dB]',{'-0.3' '0.0' '0.3'},{'2' '4' '6' '8'});
%           sh = gensubpl('lb',3,4,0.95,0.8,'t [ms]','U [uV]');
%
% INPUT ARGUMENTS
%
% 1. mode   'h' or 'v' : count quicker in horizontal  (default) or vertical direction  
%           't' or 'b' : first subplot is at the top  (default) or bottom row
%           'l' or 'r' : first subplot is at the left (default) or right  column
%           The 8 possibilities for the example H=3 and V=2 are:
%        
%           'htl': 1 2 3    'htr': 3 2 1    'hbl': 4 5 6    'hbr': 6 5 4
%                  4 5 6           6 5 4           1 2 3           3 2 1
%
%           'vtl': 1 3 5    'vtr': 5 3 1    'vbl': 2 4 6    'vbr': 6 4 2
%                  2 4 6           6 4 2           1 3 5           5 3 1
%
%           'm' return a subplot-handle-matrix rather than a vector.
%               CAUTION: in v-mode sh is a normal     matrix Nrows x Ncolumns
%                        in h-mode sh is a transposed matrix Ncolums x Nrows
%           'n' enumarate the subplots to see how they are arranged, a test
%           'o' for with outer axis, only in this case hin, vin, hout, vout, htl, vtl are used                                 5 6
%               this mode (introducing an outer axis) somehow disables zooming in the subplots.
%               I don't know how to avoid that
% 2. H      number of horizontal subplots (= number of columns)
% 3. V      number of vertical   subplots (= number of rows   )
% 4. hf     horizontal visible fraction, 0 <= hf <= 1, hf=1: neighbouring axis touch
% 5. vf     vertical   visible fraction, 0 <= vf <= 1, hf=1: neighbouring axis touch
% 6. hin    string with xlabel of the inner horizontal axis
% 7. vin    string with ylabel of the inner vertical   axis
% 8. hout   string with xlabel of the outer horizontal axis
% 9. vout   string with ylabel of the outer vertical   axis
%10. htl    cell array with xticklabels on the horizontal axis, only for the lower row
%11. vtl    cell array with yticklabels on the vertical   axis, only for the left  row
%
% OUTPUT ARGUMENTS
%
% 1. sh     the subplot handles needed to plot something into the subplots
%           sh can be returned as 
%           - vector (default) , then, e.g., write subplot(sh(n))  ; plot(x);
%           - matrix (mode 'm'), then, e.g., write subplot(sh(j,k)); plot(x);
%             in h-mode, the first index runs horizontal (along the columns)
%             in v-mode, the first index runs vertical   (along the rows)
%
% AUTHOR: Helmut Riedel, April 2000
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% 1. default handling %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

if nargin < 11 vtl  = {'-12' '0' '12'}     ; end
if nargin < 10 htl  = {'-0.4' '0.0' '0.4'} ; end
if nargin <  9 vout = 'ILD [dB]'           ; end
if nargin <  8 hout = 'ITD [ms]'           ; end
if nargin <  7 vin  = 'voltage [uV]'       ; end
if nargin <  6 hin  = 'time [ms]'          ; end
if nargin <  5 vf   = 0.98                 ; end
if nargin <  4 hf   = 0.98                 ; end
if nargin <  3 V    =  3                   ; end
if nargin <  2 H    =  3                   ; end
if nargin <  1 mode = 'htl'                ; end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% 2. check consistency of mode and set mode defaults %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

if isempty(mode)
  mode = 'x';                      % avoid stupid warning
end

if find(mode=='h') & find(mode=='v')
  error('gensubpl: mode cannot contain h(orizontal) and v(ertical).');
end
if find(mode=='t') & find(mode=='b')
  error('gensubpl: mode cannot contain t(op) and b(ottom).');
end
if find(mode=='l') & find(mode=='r')
  error('gensubpl: mode cannot contain l(eft) and r(ight).');
end

if isempty(find(mode=='h')) & isempty(find(mode=='v'))  % no 'h' or 'v' ?
  mode = [mode 'h'];                                    % set default horizontal
end
if isempty(find(mode=='t')) & isempty(find(mode=='b'))  % no 't' or 'b' ?
  mode = [mode 't'];                                    % set default top
end
if isempty(find(mode=='l')) & isempty(find(mode=='r'))  % no 'l' or 'r' ?
  mode = [mode 'l'];                                    % set default left
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% 2. define positions using the default mode 'htl': horizontal, from top and left %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
HV = H*V;                          % total number of subplots
sh = zeros(HV,1);                  % vector with the handles of the subplots

if find(mode=='o')                 % some space is needed for the outer axis
  h0 = 0.19;                         % horizontal origin
  v0 = 0.19;                         % vertical   origin
  hw = 0.76/H;                       % horizontal width
  vw = 0.76/V;                       % vertical   width
else                               % bigger subplots possible, no space for outer axis
  h0 = 0.12;                         % horizontal origin
  v0 = 0.12;                         % vertical   origin
  hw = 0.83/H;                       % horizontal width
  vw = 0.83/V;                       % vertical   width
end %'o'

h = h0 + hw*rem(0:HV-1,H);          % = h0 + hw*[0 1 2 ... H 0 1 2 ... H 0 1 2 ... H];
v = v0 + vw*floor((HV-1:-1:0)/H);   % = v0 + vw*[V V   ... V-1 V-1 ... 1 1 1 ... 0 0];
%h = h0 + hw*floor((HV-1:-1:0)/H);  % = h0 + hw*[V V   ... V-1 V-1 ... 1 1 1 ... 0 0];
%v = v0 + vw*rem(HV-1:-1:0,H);      % = v0 + vw*[H H-1 ... 1 0 H ...   1 0 H ... 1 0];

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% 3. generate figure with subplots at positions determined by vectors h and v %%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
fignum=figure; set(gcf,'units','normalized','position',[0.5 0.1 0.49 0.7]);
for hv=1:HV
  sh(hv)=subplot('position',[h(hv) v(hv) hf*hw vf*vw]);
  set(gca,'xticklabel',[]); set(gca,'yticklabel',[]);  % clear ticklabels
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% 4. permute the handle vector sh according to mode %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
sh = reshape(sh,[H V])';          % change to sh to matrix for permutations
                                  % transpose because matlab counts quicker vertically
if find(mode=='b')                % bottom desired instead of default top ?
  sh = flipud(sh);                % flip handle matrix up-down
end

if find(mode=='r')                % right desired instead of default left ?
  sh = fliplr(sh);                % flip handle matrix left-right
end

if find(mode=='h')                % quicker counting horizontal desired ?
  sh = sh';                       % transpose sh (after tb- and lr-flips !)
end

if isempty(find(mode=='m'))       % vector possibly better, caution with matrix
  sh = sh(:);                     % because of different orders in h- and v-case
end % ~'m'                        % normal matrix order in v-mode, reversed for h

if find(mode=='n')                % number mode, write numbers of subplots into them
  fontsize = floor(min(80,80*15/HV));
  for hv=1:HV
    subplot(sh(hv)); 
    text(0.5,0.5,num2str(hv),'HorizontalAlignment','center','Fontsize',fontsize);
  end %hv
end %'n'

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% 6. outer coordinate system, caution, this inhibits zooming into the subplots %%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if find(mode=='o')
  axes('position',[0 0 1 1]); axis([0 1 0 1]); axis('off')
  text(0.98,0.12,hin ,'HorizontalAlignment','right');               % inner xlabel
  text(0.12,0.98,vin ,'HorizontalAlignment','right','rotation',90); % inner ylabel

  text(1.00,0.02,hout,'HorizontalAlignment','right','fontsize',16) % outer xlabel
  text(0.03,1.00,vout,'HorizontalAlignment','right','rotation',90,'fontsize',16) % o y

  hl = 0.08; vl=0.08;
  line([hl 0.98],[vl vl  ],'color','k');                   % outer horizontal line
  line([hl hl  ],[vl 0.98],'color','k');                   % outer vertical   line

  for hh=1:min(H,length(htl))
    line([h(hh)+hf*hw/2 h(hh)+hf*hw/2],[vl-0.01 vl+0.01],'color','k');% outer xticks
    text(h(hh)+hf*hw/2,vl-0.04,htl{hh},'HorizontalAlignment','center','fontsize',16);
  end %hh                                                       % outer xticklabels
  for vv=1:min(V,length(vtl))
    line([hl-0.01 hl+0.01],[v(H*vv)+vf*vw/2 v(H*vv)+vf*vw/2],'color','k');%  outer yticks
    text(hl-0.02,v(H*vv)+0.50*vf*vw,vtl{vv},'HorizontalAlignment','right','fontsize',16);
  % text(hl-0.02,v(H*vv)+0.48*vf*vw,vtl{vv},'HorizontalAlignment','right','fontsize',16);
  % note: correct height in matlab-plot with 0.48*vf*vw but:
  %       correct height in eps-file    with 0.50*vf*vw
  end %vv                                                       % outer yticklabels
end %'o'

return

%---------------------------------------------------------------------
function clear_inner_ticklabels(sh)
%
% clear_inner_ticklabels -- clears the inner ticklabels in a HxV-subplot
%
% usage   : clear_inner_ticklabels(sh);
% example : clear_inner_ticklabels(sh);
%
% INPUT ARGUMENTS
%
% 1. sh     vector or matrix of the subhandles to the subplots,
%           e.g., returned from gensubpl.m
%
% OUTPUT ARGUMENTS
%
% none
%
% AUTHOR: Helmut Riedel, April 2000

if ~nargin help clear_inner_ticklabels; return; end 

HV = prod(size(sh));                      % HxV is number of subplots
pos = zeros(HV,4);                        % for each subplot [hmin vmin width height]
for hv = 1:HV
  pos(hv,:) = get(subplot(sh(hv)),'position');
% subplot(sh(hv)); plot(rand(50,1));      % test: generate labels to clear them later
end %hv

hclear = find(min(pos(:,2)) ~= pos(:,2)); % clear h where v-position is not minimal
vclear = find(min(pos(:,1)) ~= pos(:,1)); % clear v where h-position is not minimal

for hv = 1:length(hclear)
  set(sh(hclear(hv)),'xticklabel','');
end

for hv = 1:length(vclear)
  set(sh(vclear(hv)),'yticklabel','');
end

return

%%-----------------------------------------------------------------------------
%%
%%   Copyright (C) 2000-2004   
%%   Medizinische Physik,
%%   Universitaet Oldenburg, Germany
%%   All rights reserved. 
%%   http://www.physik.uni-oldenburg.de/docs/medi
%%
%%   Permission to use, copy, and distribute this software/file and its
%%   documentation for any purpose without permission by UNIVERSITAET OLDENBURG
%%   is not granted.
%%   
%%   Permission to use this software for purely research (excluding weapons 
%%   research) or educational purposes is granted, with the exception that 
%%   modified versions of the code may not be redistributed unless permission 
%%   has been obtained separately from UNIVERSITAET OLDENBURG.
%%
%%   Permission to use this software for weapons research or applications is 
%%   not granted.
%%
%%   No commercial exploitation of this software is permitted unless permission 
%%   has been obtained separately from UNIVERSITAET OLDENBURG. 
%%
%%   This software is provided "as is" without expressed or implied warranty.
%%
%%   Author:    Michael Kleinschmidt
%%   Co-Author: Bernd Meyer 
%%
%%   Please contact Bernd Meyer (bernd.meyer@uni-oldenburg.de) for 
%%   questions regarding this release.
%%----------------------------------------------------------------------------- 