function result_plotter_std(corpus, selection, testlist, labellist)

% function result_plotter_std(corpus, selection, testlist, labellist)
% 
% plot results of several test conditions
%
% trialname: string defining trial and parameters (define before first use!!!)
% testlist: test conditions
% labellist: test labels
%
% Ex.: result_plotter_std('zifkom','directions', {'clean' 'noisy'}, {'clean' 'noisy'})
%
% result_plotter_std('zifkom','Boost-nonBoost2', {'nsmalltrain' 'small' 'smalnoisy'}, {'noisy train' 'clean test' 'noisy test'})
% result_plotter_std('zifkom','Boost-nonBoost6', {'trainnoisy' 'clean' 'noisy'}, {'noisy train' 'clean test' 'noisy test'})
%
% (c) Universitaet Oldenburg
%
% Michael Kleinschmidt, Universitt Oldenburg, Jun 2001/Feb 2003

if strcmp(selection,'directions')
    triallist = {'noisy_ComplexGabor_s_and_t_and_ST_fdim23_abs_80Feat_500Iter' 'noisy_ComplexGabor_s_only_fdim23_abs_80Feat_500Iter' 'noisy_ComplexGabor_t_only_fdim23_abs_80Feat_500Iter' 'noisy_ComplexGabor_sandt_only_fdim23_abs_80Feat_500Iter' 'noisy_ComplexGabor_ST_only_fdim23_abs_80Feat_500Iter' 'noisy_ComplexGabor_STup_only_fdim23_abs_80Feat_500Iter' 'noisy_ComplexGabor_STdown_only_fdim23_abs_80Feat_500Iter'};
    triallabels = {'stST' 's' 't' 'st' 'ST' 'STup' 'STdown'}
    
elseif strcmp(selection,'clean_noisy_train')
    triallist = {'clean_ComplexGabor_s_and_t_and_ST_fdim23_abs_80Feat_500Iter' 'noisy_ComplexGabor_s_and_t_and_ST_fdim23_abs_80Feat_500Iter'};
    triallabels = {'clean' 'noisy'}
    
elseif strcmp(selection,'LP')
    triallist = {'noisy_ComplexGabor_ST_only_fdim23_abs_80Feat_300Iter_2FmodTmin_3FmodTmax' 'noisy_ComplexGabor_ST_only_fdim23_abs_80Feat_300Iter_2FmodTmin_4FmodTmax' 'noisy_ComplexGabor_ST_only_fdim23_abs_80Feat_300Iter_2FmodTmin_8FmodTmax' 'noisy_ComplexGabor_ST_only_fdim23_abs_80Feat_300Iter_2FmodTmin_16FmodTmax' 'noisy_ComplexGabor_ST_only_fdim23_abs_80Feat_300Iter_2FmodTmin_32FmodTmax' 'noisy_ComplexGabor_ST_only_fdim23_abs_80Feat_500Iter' };
    triallabels = {'3' '4' '8' '16' '32' '50'}
    
elseif strcmp(selection,'HP')
    triallist = {'noisy_ComplexGabor_ST_only_fdim23_abs_80Feat_500Iter' 'noisy_ComplexGabor_ST_only_fdim23_abs_80Feat_300Iter_4FmodTmin_50FmodTmax' 'noisy_ComplexGabor_ST_only_fdim23_abs_80Feat_300Iter_8FmodTmin_50FmodTmax' 'noisy_ComplexGabor_ST_only_fdim23_abs_80Feat_300Iter_16FmodTmin_50FmodTmax' 'noisy_ComplexGabor_ST_only_fdim23_abs_80Feat_300Iter_32FmodTmin_50FmodTmax' };
    triallabels = {'2' '4' '8' '16' '32'}
    
elseif strcmp(selection,'Boost-nonBoost')
    triallist = {'small_ComplexGabor_s_and_t_only_fdim23_abs_10Feat_50Iter_1BoostIt' 'small_ComplexGabor_s_and_t_only_fdim23_abs_10Feat_25Iter_2BoostIt' 'small_ComplexGabor_s_and_t_only_fdim23_abs_10Feat_25Iter_2BoostIt' };
    triallabels = {'10 F * 1 BIt' '5 F * 2 BIt' '2 F * 5 BIt'}
    
elseif strcmp(selection,'Boost-nonBoost2')
    triallist = {'small_ComplexGabor_s_and_t_and_ST_fdim23_abs_10Feat_50Iter_1BoostIt' 'small_ComplexGabor_s_and_t_and_ST_fdim23_abs_10Feat_25Iter_2BoostIt' 'small_ComplexGabor_s_and_t_and_ST_fdim23_abs_10Feat_25Iter_2BoostIt' };
    triallabels = {'10 F * 1 BIt' '5 F * 2 BIt' '2 F * 5 BIt'}  
    
elseif strcmp(selection,'Boost-nonBoost3')
    triallist = {'nsmall_ComplexGabor_s_and_t_only_fdim23_abs_10Feat_50Iter_1BoostIt' 'nsmall_ComplexGabor_s_and_t_only_fdim23_abs_10Feat_25Iter_2BoostIt' 'nsmall_ComplexGabor_s_and_t_only_fdim23_abs_10Feat_25Iter_2BoostIt' };
    triallabels = {'10 F * 1 BIt' '5 F * 2 BIt' '2 F * 5 BIt'}  
    
elseif strcmp(selection,'Boost-nonBoost4')
    triallist = {'nsmall_ComplexGabor_s_and_t_and_ST_fdim23_abs_10Feat_50Iter_1BoostIt' 'nsmall_ComplexGabor_s_and_t_and_ST_fdim23_abs_10Feat_25Iter_2BoostIt' 'nsmall_ComplexGabor_s_and_t_and_ST_fdim23_abs_10Feat_25Iter_2BoostIt' };
    triallabels = {'10 F * 1 BIt' '5 F * 2 BIt' '2 F * 5 BIt'}  
    
elseif strcmp(selection,'Boost-nonBoost5')
    triallist = {'clean_ComplexGabor_s_and_t_and_ST_fdim23_abs_40Feat_200Iter_1BoostIt' 'clean_ComplexGabor_s_and_t_and_ST_fdim23_abs_40Feat_100Iter_2BoostIt' 'clean_ComplexGabor_s_and_t_and_ST_fdim23_abs_40Feat_50Iter_4BoostIt' };
    triallabels = {'40 F  * 1 BIt' '20 F * 2 BIt' '10 F * 4 BIt'} 
    
elseif strcmp(selection,'Boost-nonBoost6')
    triallist = {'noisy_ComplexGabor_s_and_t_and_ST_fdim23_abs_40Feat_200Iter_1BoostIt' 'noisy_ComplexGabor_s_and_t_and_ST_fdim23_abs_40Feat_100Iter_2BoostIt' 'noisy_ComplexGabor_s_and_t_and_ST_fdim23_abs_40Feat_50Iter_4BoostIt' };
    triallabels = {'40 F  * 1 BIt' '20 F * 2 BIt' '10 F * 4 BIt'} 
    
elseif strcmp(selection,'Boost-nonBoost-TInoisy')
    triallist = {'noisy_ComplexGabor_s_and_t_and_ST_fdim23_abs_60Feat_300Iter_1BoostIt' 'noisy_ComplexGabor_s_and_t_and_ST_fdim23_abs_60Feat_150Iter_2BoostIt' 'noisy_ComplexGabor_s_and_t_and_ST_fdim23_abs_60Feat_75Iter_4BoostIt' 'noisy_ComplexGabor_s_and_t_and_ST_fdim23_abs_60Feat_50Iter_6BoostIt' };
    triallabels = {'60 F  * 1 BIt' '30 F * 2 BIt' '15 F * 4 BIt' '10 F * 6 BIt'} 

elseif strcmp(selection,'Boost-nonBoost-TIclean')
    triallist = {'clean_ComplexGabor_s_and_t_and_ST_fdim23_abs_60Feat_300Iter_1BoostIt' 'clean_ComplexGabor_s_and_t_and_ST_fdim23_abs_60Feat_150Iter_2BoostIt' 'clean_ComplexGabor_s_and_t_and_ST_fdim23_abs_60Feat_75Iter_4BoostIt' 'clean_ComplexGabor_s_and_t_and_ST_fdim23_abs_60Feat_50Iter_6BoostIt' };
    triallabels = {'60 F  * 1 BIt' '30 F * 2 BIt' '15 F * 4 BIt' '10 F * 6 BIt'} 
    
end

figure(1)

%Lade

counter=0;
for trialname=triallist
    
    counter=counter+1
    
    NCopy=1;
    ['testdir\' corpus '_' char(trialname) '_' num2str(NCopy) '.mat']
    fprintf('loading %s\n',['testdir\' corpus '_' char(trialname) '_' num2str(NCopy) '.mat'])
    while (fileExists(['testdir/' corpus '_' char(trialname) '_' num2str(NCopy) '.mat']))
        fprintf('loading %s\n',['testdir\' corpus '_' char(trialname) '_' num2str(NCopy) '.mat'])
        Ntest=0;
        for testname=testlist % Iteriere alle trials
            Ntest=Ntest+1;
            eval(['load testdir/' corpus '_' char(trialname)  '_' num2str(NCopy) '-' char(testname) '.mat res']);
            testres(NCopy,Ntest)=res.rate;
            clear res
        end
        NCopy=NCopy+1;
    end
    
    testres
    testmean(counter,:)=mean(testres,1)
    teststd(counter,:)=std(testres,0,1)
    
    
    
    clear testres;
    
end

%Plotte

farbe='brcgmbrcgmbrcgmbrcgmbrcgmbrcgm';
art='osx+*ds<>x+*ds<>x+*ds<>x+*ds<>x';
close(1)
figure(1)
hold on

if length(testlist)==2
    plot(-100,-100,[farbe(1) art(1)],-100,-100,[farbe(2) art(2)])
end

Ntest=0;
for testname=testlist % Iteriere alle trials
    Ntest=Ntest+1;
    
    errorbar(1:length(triallist), (100-testmean(:,Ntest)*100), teststd(:,Ntest)*100, [farbe(Ntest) art(Ntest)])
    ylabel('Classification error [%]')
    set(gca, 'xtick', [1:length(triallabels)]);
    set(gca, 'xticklabel', char(triallabels));
end

ax=axis;
axis([0 length(triallist)+1  0 ax(4)])

legend(labellist)
legend('boxoff')

hold off


% save
%eval(['print -depsc -f1 Abbildungen/' trialname  '_all_WER.eps']);
%eval(['print -dtiff -f1 Abbildungen/' trialname  '_all_WER.tif']);


%%-----------------------------------------------------------------------------
%%
%%   Copyright (C) 2000-2004   
%%   Medizinische Physik,
%%   Universitaet Oldenburg, Germany
%%   All rights reserved. 
%%   http://www.physik.uni-oldenburg.de/docs/medi
%%
%%   Permission to use, copy, and distribute this software/file and its
%%   documentation for any purpose without permission by UNIVERSITAET OLDENBURG
%%   is not granted.
%%   
%%   Permission to use this software for purely research (excluding weapons 
%%   research) or educational purposes is granted, with the exception that 
%%   modified versions of the code may not be redistributed unless permission 
%%   has been obtained separately from UNIVERSITAET OLDENBURG.
%%
%%   Permission to use this software for weapons research or applications is 
%%   not granted.
%%
%%   No commercial exploitation of this software is permitted unless permission 
%%   has been obtained separately from UNIVERSITAET OLDENBURG. 
%%
%%   This software is provided "as is" without expressed or implied warranty.
%%
%%   Author:    Michael Kleinschmidt
%%   Co-Author: Bernd Meyer 
%%
%%   Please contact Bernd Meyer (bernd.meyer@uni-oldenburg.de) for 
%%   questions regarding this release.
%%----------------------------------------------------------------------------- 