function [vSecondary] = FastCalcGaborMany(sPrimary, sSelectSet)

% Function for fast calculation Gabor features for a number of mIR's (spectro-temporal representation)
%
% ONE Gabor function !!! yields one features only ! Use for fast computing!
% works for abs, real and imag only
%
% call by:
% [vSecondary] = ReCalcGaborMany(sPrimary, prototype)
% 
% IN:
% sPrimary = array of structures containing
%   - mIR : input feature matrix
%   - vLabel : label vector
% prototype: parameters for one Gabor function
%
% OUT:
% vSecondary = vector of feature values for all points in time 
%
% Michael Kleinschmidt, ICSI, Feb 2002

if nargin ~= 2
   error('Incorrect number of parameters !')
end

visual = 0;

vSecondary = [];
for k = 1:length(sPrimary)
  
  vTemp = FastCalcGaborFeat(sPrimary(k).mIR, sSelectSet, visual);
  
  if strcmp(sSelectSet.activation, 'no')
	vSecondary = [vSecondary vTemp];
  elseif strcmp(sSelectSet.activation, 'abs')
	vSecondary = [vSecondary sum(abs(vTemp))];
  elseif strcmp(sSelectSet.activation, 'greater_zero')
	vSecondary = [vSecondary sum(abs(vTemp)+vTemp)/2];
  elseif strcmp(sSelectSet.activation, 'less_zero')
	vSecondary = [vSecondary sum(abs(vTemp)-vTemp)/2];
  else
	error(['activation unknown: ' sSelectSet.activation])
  end
end

return
%%-----------------------------------------------------------------------------
%%
%%   Copyright (C) 2000-2004   
%%   Medizinische Physik,
%%   Universitaet Oldenburg, Germany
%%   All rights reserved. 
%%   http://www.physik.uni-oldenburg.de/docs/medi
%%
%%   Permission to use, copy, and distribute this software/file and its
%%   documentation for any purpose without permission by UNIVERSITAET OLDENBURG
%%   is not granted.
%%   
%%   Permission to use this software for purely research (excluding weapons 
%%   research) or educational purposes is granted, with the exception that 
%%   modified versions of the code may not be redistributed unless permission 
%%   has been obtained separately from UNIVERSITAET OLDENBURG.
%%
%%   Permission to use this software for weapons research or applications is 
%%   not granted.
%%
%%   No commercial exploitation of this software is permitted unless permission 
%%   has been obtained separately from UNIVERSITAET OLDENBURG. 
%%
%%   This software is provided "as is" without expressed or implied warranty.
%%
%%   Author:    Michael Kleinschmidt
%%   Co-Author: Bernd Meyer 
%%
%%   Please contact Bernd Meyer (bernd.meyer@uni-oldenburg.de) for 
%%   questions regarding this release.
%%----------------------------------------------------------------------------- 
