function [Param,Data]=InitializeSet(Param,Data)

% initialize feature set and train net for the first time before iteration 1

Data.TRAIN.mSecondaryRefined=[];

for k=1:Param.featurenum
    
    disp(['Calculate feature # ' num2str(k)]);
    
    ok=0;
    while ~ok
        % randomly choose one Gabor feature
        Param.sSelectSet(k).prototype=proto(Param);
                
        % Calculate TRAIN Gabor feature 
        Data.TRAIN.mSecondaryRefined(k,:)= FastCalcGaborMany(Data.TRAIN.sPrimary,Param.sSelectSet(k).prototype);
        
        % Check for double features
         ok=1;
         x = Data.TRAIN.mSecondaryRefined';
         c = cov(x);
         d = sqrt(diag(c));
         % avoid division by zero
         if isempty(find(d==0))
            C = c./(d*d');
            % discard new feature if correlation coefficient with old 
            % feature is too high
            if max(max(abs(C-diag(diag(C))))) > Param.SimMax
               ok=0;
            end
         else % evaluation of corrcoeff would cause division by zero, 
            % so select new feature
            disp('Computation of correlation coefficient not possible; choosing new filter function. ')
            ok = 0;
         end % of if
               
        if Param.visual
            MatrixPlotter(Data.TRAIN.mSecondaryRefined,10,'X')
        end
        
    end % of if ok
    
end % of for k

% build one big label vector
Data.TRAIN.vLabels=GetLabelVec(Data.TRAIN.sPrimary);

if findstr(Param.trialname,'_Diphone_')
    % eliminate frames with class 0
    Data.TRAIN.vLabelsfull=Data.TRAIN.vLabels;
    [Data.TRAIN.vLabels,Data.TRAIN.mSecondaryRefined]=EliminateZeroFrames(Data.TRAIN.vLabelsfull,Data.TRAIN.mSecondaryRefined);
    fprintf('keep %i out of %i frames (%4.2f percent)\n',length(Data.TRAIN.vLabels),length(Data.TRAIN.vLabelsfull),(length(Data.TRAIN.vLabels)/length(Data.TRAIN.vLabelsfull)*100));
    
elseif findstr(Param.trialname,'TIMIT_')
    fprintf('obtained %i examples out of %i files\n ',length(Data.TRAIN.vLabels),Param.trainfilenum);
else
    fprintf('neither TIMIT nor Diphone found in trialname\n')
end


if Param.visual
    figure(12)
    plot(Data.TRAIN.vLabels)
end


% Build target matrix 
Data.TRAIN.target = maketarget(Data.TRAIN.vLabels,Param.classnum);

if Param.visual
    MatrixPlotter(Data.TRAIN.mSecondaryRefined,10,'X')
    MatrixPlotter(Data.TRAIN.target,11,'Ytarget')
end

% train net for the first time

[Param.net, Param.psi] = trainer(Data.TRAIN.mSecondaryRefined, Data.TRAIN.target,Param);

% Score initial net
Param.start.TRAINRMS = RMSerror(Param.net, Data.TRAIN.mSecondaryRefined, Data.TRAIN.target,Param.Dvec);
[Param.start.res, tmp.start.TRAINYmod] = classify(Param.net, Data.TRAIN.mSecondaryRefined, Data.TRAIN.target,Param.Dvec);
Param.total.RMS(1) = Param.start.TRAINRMS;
Param.total.rate(1) = Param.start.res.rate;
Param.total.res(1) = Param.start.res;
Param.total.Dscore(1) = Param.start.res.Dscore;

fprintf('  Base rate: %4.2f \t RMS: %6.4f \t Dscore: %6.4f \n',Param.total.rate(1)*100,Param.total.RMS(1),Param.total.Dscore(1))
    
return


%%-----------------------------------------------------------------------------
%%
%%   Copyright (C) 2000-2004   
%%   Medizinische Physik,
%%   Universitaet Oldenburg, Germany
%%   All rights reserved. 
%%   http://www.physik.uni-oldenburg.de/docs/medi
%%
%%   Permission to use, copy, and distribute this software/file and its
%%   documentation for any purpose without permission by UNIVERSITAET OLDENBURG
%%   is not granted.
%%   
%%   Permission to use this software for purely research (excluding weapons 
%%   research) or educational purposes is granted, with the exception that 
%%   modified versions of the code may not be redistributed unless permission 
%%   has been obtained separately from UNIVERSITAET OLDENBURG.
%%
%%   Permission to use this software for weapons research or applications is 
%%   not granted.
%%
%%   No commercial exploitation of this software is permitted unless permission 
%%   has been obtained separately from UNIVERSITAET OLDENBURG. 
%%
%%   This software is provided "as is" without expressed or implied warranty.
%%
%%   Author:    Michael Kleinschmidt
%%   Co-Author: Bernd Meyer 
%%
%%   Please contact Bernd Meyer (bernd.meyer@uni-oldenburg.de) for 
%%   questions regarding this release.
%%----------------------------------------------------------------------------- 
