function [result, Ymod] = classify(W, X, Y, Dvec) 
% function for "testing" the weight matrix
% syntax: [result, Ymod] = classify(W,X,Y)
% example:
%
% input:
% -- W is the weight matrix of the neural net
% 
% -- Y is the target matrix (derived from the labels)
% 
% -- X is a matrix of secondary feature vectors
% MISS
% -- Dvec is the vector that contains boosting weights 
%      per example (length P)
%
% output:
% -- the result is a structure with the components 
%    - rate (recognition rate in percent)
%    - matrix (confusion matrix)
%    - Dscore (D-weighted recognition performance)
% -- Ymod is the classification matrix
%
% classify.m : Michael Kleinschmidt, AG MEDI, Uni Oldenburg   19.6.99
% classify2.m: mk   1.12.99
% classify.m : mk   20.5.00

% how many feature vector components?
temp = size(X);
N = temp(1);

% how many patterns?
P = temp(2);

% how many classes?
temp = size(Y);
M = temp(1);

% initialize confusion matrix
result.matrix = zeros(M, M);
result.Dscore = 0;

% classify
Ymod = W * X;

% compare classification with desired value
for i = 1:P
    [dummy, desired_val] = max(Y(1:M, i));
    [dummy, actual_val]  = max(Ymod(1:M, i));
    result.matrix(desired_val, actual_val) = result.matrix(desired_val, actual_val) + 1;
    result.Dscore = result.Dscore + isequal(desired_val,actual_val) * Dvec (i);
    result.vCorrect(i) = isequal(desired_val,actual_val);
end   

result.rate = trace(result.matrix) / P;

% Tino Gramss' dissertation, page 30, equation 11

return

%%-----------------------------------------------------------------------------
%%
%%   Copyright (C) 2000-2004   
%%   Medizinische Physik,
%%   Universitaet Oldenburg, Germany
%%   All rights reserved. 
%%   http://www.physik.uni-oldenburg.de/docs/medi
%%
%%   Permission to use, copy, and distribute this software/file and its
%%   documentation for any purpose without permission by UNIVERSITAET OLDENBURG
%%   is not granted.
%%   
%%   Permission to use this software for purely research (excluding weapons 
%%   research) or educational purposes is granted, with the exception that 
%%   modified versions of the code may not be redistributed unless permission 
%%   has been obtained separately from UNIVERSITAET OLDENBURG.
%%
%%   Permission to use this software for weapons research or applications is 
%%   not granted.
%%
%%   No commercial exploitation of this software is permitted unless permission 
%%   has been obtained separately from UNIVERSITAET OLDENBURG. 
%%
%%   This software is provided "as is" without expressed or implied warranty.
%%
%%   Author:    Michael Kleinschmidt
%%   Co-Author: Bernd Meyer 
%%
%%   Please contact Bernd Meyer (bernd.meyer@uni-oldenburg.de) for 
%%   questions regarding this release.
%%----------------------------------------------------------------------------- 
