function E = error_euclidian(W, X, Y)

% Calculates the total euclidian error
% Syntax: E = error_euclidian(W, X, Y)
% Example: 
%
% Input: 
% -- W is the weight matrix of the neural network 
%
% -- Y is the target matrix
%
% -- X is a matrix containing secondary feature vectors
%     where X(number of feature, number of ST representation) corresponds to features
%	
% Output:
% -- E is the total euclidian error
%
% Michael Kleinschmidt, AG MEDI, Uni Oldenburg   19.6.99

% calculate the difference between desired and actual value
difference = Y - W * X;

% calculate the total euclidian error
E = trace(difference * difference');

% Tino Gramss' dissertation, page 30, equation 13

return

%%-----------------------------------------------------------------------------
%%
%%   Copyright (C) 2000-2004   
%%   Medizinische Physik,
%%   Universitaet Oldenburg, Germany
%%   All rights reserved. 
%%   http://www.physik.uni-oldenburg.de/docs/medi
%%
%%   Permission to use, copy, and distribute this software/file and its
%%   documentation for any purpose without permission by UNIVERSITAET OLDENBURG
%%   is not granted.
%%   
%%   Permission to use this software for purely research (excluding weapons 
%%   research) or educational purposes is granted, with the exception that 
%%   modified versions of the code may not be redistributed unless permission 
%%   has been obtained separately from UNIVERSITAET OLDENBURG.
%%
%%   Permission to use this software for weapons research or applications is 
%%   not granted.
%%
%%   No commercial exploitation of this software is permitted unless permission 
%%   has been obtained separately from UNIVERSITAET OLDENBURG. 
%%
%%   This software is provided "as is" without expressed or implied warranty.
%%
%%   Author:    Michael Kleinschmidt
%%   Co-Author: Bernd Meyer 
%%
%%   Please contact Bernd Meyer (bernd.meyer@uni-oldenburg.de) for 
%%   questions regarding this release.
%%----------------------------------------------------------------------------- 
