% function [mFeat,header]=load_htk_with_header(infile,byteswap,display_flag)
function [mFeat,header]=load_htk_with_header(infile,byteswap)
byteswap = 0;
display_flag = 0;
% [mFeat,header]=load_htk_with_header(infile,byteswap,display_flag)
%
% Example: [mFeat,header]=load_htk_with_header('sponly_vmh0sx116.htk',0,1);
%
% reads HTKfile with header and displays (optional)
%
% Michael Kleinschmidt, ICSI, Oct 2001

% open file
if byteswap
  fid=fopen(infile,'r','b');
else
  fid=fopen(infile,'r');
end

% read header
[header.nSamples, count]=fread(fid,1,'int'); 
[header.sampPeriod, count]=fread(fid,1,'int'); 
[header.sampSize, count]=fread(fid,1,'short'); 
[header.sampKind, count]=fread(fid,1,'short'); 

% header

% read data
[indata, count]=fread(fid,inf,'float');
% count


% close file
fclose(fid);

% calculate feature dimension
dim=header.sampSize/4;

% rearrange vector to matrix
mFeat = reshape(indata,dim,header.nSamples);  

if display_flag
   
  % Plot

  figure
  
  y=1:1:dim;                
  len=header.nSamples*header.sampPeriod/10^7;
  x=0:header.sampPeriod/10^7:len;          
  imagesc(x, y, mFeat);%, [-0.5 1]);
  axis xy;
  colormap jet;
  set(gca,'FontSize', 20); 
  cb=colorbar;
  set(cb,'FontSize', 20); 
  
  xlabel('time in s');
  ylabel('# feature')
  
end

%%-----------------------------------------------------------------------------
%%
%%   Copyright (C) 2000-2004   
%%   Medizinische Physik,
%%   Universitaet Oldenburg, Germany
%%   All rights reserved. 
%%   http://www.physik.uni-oldenburg.de/docs/medi
%%
%%   Permission to use, copy, and distribute this software/file and its
%%   documentation for any purpose without permission by UNIVERSITAET OLDENBURG
%%   is not granted.
%%   
%%   Permission to use this software for purely research (excluding weapons 
%%   research) or educational purposes is granted, with the exception that 
%%   modified versions of the code may not be redistributed unless permission 
%%   has been obtained separately from UNIVERSITAET OLDENBURG.
%%
%%   Permission to use this software for weapons research or applications is 
%%   not granted.
%%
%%   No commercial exploitation of this software is permitted unless permission 
%%   has been obtained separately from UNIVERSITAET OLDENBURG. 
%%
%%   This software is provided "as is" without expressed or implied warranty.
%%
%%   Author:    Michael Kleinschmidt
%%   Co-Author: Bernd Meyer 
%%
%%   Please contact Bernd Meyer (bernd.meyer@uni-oldenburg.de) for 
%%   questions regarding this release.
%%----------------------------------------------------------------------------- 
