function [sPrimary]=load_many_ZIFKOM(indir)

% function [sPrimary]=load_many_ZIFKOM(indir)
% 
% reads primary features from HTK format files and attaches the correct
% frame labels (from filenames) to it. 
%
% IN:
% indir: name of directory with data to be read
%
% OUT:
% sPrimary: array of structure containing
%   - mIR : input feature matrix
%   - vLabels : label vector
% 
% based on load_many_ZIFKOM by Michael Kleinschmidt

if nargin ~= 1
   error('Incorrect number of parameters ! Use "help" for Usage !')
end

% read directory with data files
directory = dir(indir);

% set counter to 0
n=0;

% input loop (1st entry is '.', 2nd is '..')
for i=3:length(directory)
   if findstr(directory(i).name,'.htk')	        
       
	 % enumeration of data files
	 n = n + 1;
	 % disp(['Load file # ' num2str(n) ', ' directory(i).name])
	 if (i-2)/200==floor((i-2)/200)
         fprintf('Load file # %i\r',n)
     end
	 % generate string with data and label file with path information
	 datafile  = [indir '/' directory(i).name];
      
      % read spectro-temporal representation from data file
      mIR=load_htk_byteswap(datafile,0,0);
	  
      many(n).mIR = mIR;
      
      % read label filename
      % OLLO naming convention is 
      % S01F_L001_V1_M1_N1_CS0.wav
      % S[Speaker ID][Gender flag]_L[logatome number]_V[number of
      % variability]_M[mic number]_N[repetition number]_CS[click in speech
      % flag].wav
      % the following logatomes were chosen as targets: 
      % affa (L005) ezze (L024) immi (L039) ollo (L056) unnu (L068)
      % siss (L092) tutt (L104) pahp (L118) pehp (L126) fief (L131)
      
      % set appropriate labels (L5 -> 1, L24 -> 2 aso)
      iLogatomeNumber = str2num(directory(i).name(7:9));
      if (iLogatomeNumber == 5);many(n).vLabels = 1;
      elseif (iLogatomeNumber == 24); many(n).vLabels = 2;
      elseif (iLogatomeNumber == 39); many(n).vLabels = 3;
      elseif (iLogatomeNumber == 56); many(n).vLabels = 4;
      elseif (iLogatomeNumber == 68); many(n).vLabels = 5;
      elseif (iLogatomeNumber == 92); many(n).vLabels = 6;
      elseif (iLogatomeNumber == 104); many(n).vLabels = 7;
      elseif (iLogatomeNumber == 118); many(n).vLabels = 8;
      elseif (iLogatomeNumber == 126); many(n).vLabels = 9;
      elseif (iLogatomeNumber == 131); many(n).vLabels = 10; 
      else
         disp(['iLogatomeNumber is ' iLogatomeNumber]);
         error('load_many_OLLO: don''t know how to label this file')
      end
               
      % determine order
      A(n)=many(n).vLabels;
      
   end    
end

% sort by classes
[Y,I]=sortrows(A');

sPrimary=many;

for i=1:n
   % resort structure
   sPrimary(i)=many(I(i));
end  

return


%%-----------------------------------------------------------------------------
%%
%%   Copyright (C) 2000-2004   
%%   Medizinische Physik,
%%   Universitaet Oldenburg, Germany
%%   All rights reserved. 
%%   http://www.physik.uni-oldenburg.de/docs/medi
%%
%%   Permission to use, copy, and distribute this software/file and its
%%   documentation for any purpose without permission by UNIVERSITAET OLDENBURG
%%   is not granted.
%%   
%%   Permission to use this software for purely research (excluding weapons 
%%   research) or educational purposes is granted, with the exception that 
%%   modified versions of the code may not be redistributed unless permission 
%%   has been obtained separately from UNIVERSITAET OLDENBURG.
%%
%%   Permission to use this software for weapons research or applications is 
%%   not granted.
%%
%%   No commercial exploitation of this software is permitted unless permission 
%%   has been obtained separately from UNIVERSITAET OLDENBURG. 
%%
%%   This software is provided "as is" without expressed or implied warranty.
%%
%%   Author:    Michael Kleinschmidt
%%   Co-Author: Bernd Meyer 
%%
%%   Please contact Bernd Meyer (bernd.meyer@uni-oldenburg.de) for 
%%   questions regarding this release.
%%----------------------------------------------------------------------------- 