function [sPrimary]=load_many_TIdigits(indir)

% function [sPrimary]=load_many_TIdigits(indir)
% 
% reads primary features from HTK format files and attaches the correct
% word labels to it. looks into all subdirs. TIdigits
%
% IN:
% indir : string containing root feature directory (looks into all subdirs)
%
% OUT:
% sPrimary: array of structure containing
%   - mIR : input feature matrix
%   - vLabels : label vector
%
% Michael Kleinschmidt, ICSI, Nov 2001
% mk, ICSI, Jan 2002 (change for TIdigits)

if nargin ~= 1
   error('Incorrect number of parameters ! Use "help" for Usage !')
end

% Read dir with subdirs
RootDirectory = dir(indir);

%disp(indir)

% set counter to 0
n=0;

% loop over directory listing (1st element is '.', 2nd is '..')
for k=3:length(RootDirectory)
    
  
  % read directory with datafiles
  sDirectory = dir([indir '/' RootDirectory(k).name]);

  % loop over directory listing (1st element is '.', 2nd is '..')
  for i=3:length(sDirectory)
	
	if findstr(sDirectory(i).name,'.htk')
	  
	  % enumeration of data files
	  n = n + 1;
	  
	  % generate string with data and labelfile with path information
          datafile  = [indir '/' RootDirectory(k).name '/' sDirectory(i).name];
	  
	  % read spectro-temporal (aka internal) representation from data file
	  mIR=load_htk(datafile,0);
	  
	  many(n).mIR = mIR(1:23,:);
	  
	  % read and interpret label from filename
	  class = sDirectory(i).name(length(sDirectory(i).name)-5);
	  if strcmp(class,'Z')
		many(n).vLabels = 11;
	  elseif strcmp(class,'O')
		many(n).vLabels = 10;
	  else
		many(n).vLabels = str2num(class);
	  end
	  
	  % determine order
	  A(n)=many(n).vLabels;
	  
	  if 0
		figure(3)
		imagesc(many(n).mIR)
		axis xy
		cla=class
		lab=many(n).vLabels
		pause
	  end
	end    
  end
end
% sort by classes
[Y,I]=sortrows(A');

sPrimary=many;

for i=1:n
   % sort structure
   sPrimary(i)=many(I(i));
end  

return
%%-----------------------------------------------------------------------------
%%
%%   Copyright (C) 2000-2004   
%%   Medizinische Physik,
%%   Universitaet Oldenburg, Germany
%%   All rights reserved. 
%%   http://www.physik.uni-oldenburg.de/docs/medi
%%
%%   Permission to use, copy, and distribute this software/file and its
%%   documentation for any purpose without permission by UNIVERSITAET OLDENBURG
%%   is not granted.
%%   
%%   Permission to use this software for purely research (excluding weapons 
%%   research) or educational purposes is granted, with the exception that 
%%   modified versions of the code may not be redistributed unless permission 
%%   has been obtained separately from UNIVERSITAET OLDENBURG.
%%
%%   Permission to use this software for weapons research or applications is 
%%   not granted.
%%
%%   No commercial exploitation of this software is permitted unless permission 
%%   has been obtained separately from UNIVERSITAET OLDENBURG. 
%%
%%   This software is provided "as is" without expressed or implied warranty.
%%
%%   Author:    Michael Kleinschmidt
%%   Co-Author: Bernd Meyer 
%%
%%   Please contact Bernd Meyer (bernd.meyer@uni-oldenburg.de) for 
%%   questions regarding this release.
%%----------------------------------------------------------------------------- 