function [sPrimary]=load_many_ZIFKOM(indir)

% function [sPrimary]=load_many_ZIFKOM(indir)
% 
% reads primary features from HTK format files and attaches the correct
% frame labels (from filenames) to it. 
%
% IN:
% indir: name of directory with data to be read
%
% OUT:
% sPrimary: array of structure containing
%   - mIR : input feature matrix
%   - vLabels : label vector
%
% Michael Kleinschmidt, ICSI, Nov 2001
% for zifkom: Jan 2002

if nargin ~= 1
   error('Incorrect number of parameters ! Use "help" for Usage !')
end

% read directory with data files
directory = dir(indir);

% set counter to 0
n=0;

% input loop (1st entry is '.', 2nd is '..')
for i=3:length(directory)
    
   if findstr(directory(i).name,'.htk')	        
       
	 % enumeration of data files
	 n = n + 1;
	 
	 if (i-2)/200==floor((i-2)/200)
         fprintf('Load file # %i\r',n)
     end
	 % generate string with data and label file with path information
	 datafile  = [indir '/' directory(i).name];
      
      % read spectro-temporal representation from data file
      mIR=load_htk(datafile,0);
	  
      many(n).mIR = mIR;
      
      % read label filename
      many(n).vLabels = str2num(directory(i).name(7:8))+1;
      
      % determine order
      A(n)=many(n).vLabels;
      
   end    
end

% sort by classes
[Y,I]=sortrows(A');

sPrimary=many;

for i=1:n
   % resort structure
   sPrimary(i)=many(I(i));
end  

return
%%-----------------------------------------------------------------------------
%%
%%   Copyright (C) 2000-2004   
%%   Medizinische Physik,
%%   Universitaet Oldenburg, Germany
%%   All rights reserved. 
%%   http://www.physik.uni-oldenburg.de/docs/medi
%%
%%   Permission to use, copy, and distribute this software/file and its
%%   documentation for any purpose without permission by UNIVERSITAET OLDENBURG
%%   is not granted.
%%   
%%   Permission to use this software for purely research (excluding weapons 
%%   research) or educational purposes is granted, with the exception that 
%%   modified versions of the code may not be redistributed unless permission 
%%   has been obtained separately from UNIVERSITAET OLDENBURG.
%%
%%   Permission to use this software for weapons research or applications is 
%%   not granted.
%%
%%   No commercial exploitation of this software is permitted unless permission 
%%   has been obtained separately from UNIVERSITAET OLDENBURG. 
%%
%%   This software is provided "as is" without expressed or implied warranty.
%%
%%   Author:    Michael Kleinschmidt
%%   Co-Author: Bernd Meyer 
%%
%%   Please contact Bernd Meyer (bernd.meyer@uni-oldenburg.de) for 
%%   questions regarding this release.
%%----------------------------------------------------------------------------- 