function [Param] = test_ffnn(Param);

% Function for test of FFNN 
% 
% Usage:
% function [Param] = test_ffnn(Param);
%
% Input:
% - Param : Structure of Parameters
%
% Output:
% - Param : Structure of Parameters
%
% Michael Kleinschmidt, AG MEDI, Uni Oldenburg   20.5.00
% modified by Michael Kleinschmidt, ICSI, Nov 2001
% and by Michael Kleinschmidt, ICSI, Jan 2002
% Universitt Oldenburg, May 2003

% changes 
% mk, 20.11.99 (added dim, traindir und testdir as options)
% mk, 23.11.99 (added headeroffset as option)
% mk, 4.2.00 (quickstart, windowpositions, projection)
% mk, 8.2.00 (mean and std calculation)
% mk, 14.2.00 (noisedir als option)
% mk, 29.2.00 (projection, mean und std nur bei schranke < 1)
% mk, 20.5.00 (ffnn -> train_ffnn)
% hg, 08.03.01 ( faster substitution method )
% mk, 4/01 (keeps best set of features on train/validation data)
% mk, 17.07.01 (revision leading to FFNN 2.0)
% mk, ICSI, Nov 2001 (adapt to Gabor and large corpora!!!)
% mk, ICSI, Jan 2002 (use fast algos for phoneme targets)
% mk, ICSI, Jan 2002 (word targets and integration over whole utterance,
% i.e. isolated words)
% mk, ICSI, Feb 2002 (now for continuous Parameters)
% mk, Oldenburg, May 2003 (includes AdaBoost)
% bm, Oldenburg, Jul 2004 (added hanning envelope as alternative)

if nargin ~= 1
    error('must be called with one parameter only!')
end
    
% now test on cv
eval(['load testdir/' Param.trialname ' Test']);

for t = 1:length(Param.Testdatatype);
    
    disp(['Test on ' char(Param.Testdatatype(t)) ' cv data'])
    
    % Load input data
    Data.CV.sPrimary=LoadIR(Param.CV.PrimeFeatDir(t).name,Param,Param.alltrainnum+1,Param.allcvnum);
    Data.CV.mSecondaryRefined = [];
    
    fprintf('Calculate Feature # ') 
    for k = 1:Test.featurenum
        
        fprintf('%i\t', k)
        
        % Calculate CV Gabor feature 
        Data.CV.mSecondaryRefined(k, :) = FastCalcGaborMany(Data.CV.sPrimary, Test.sSelectSet(k).prototype);
        
    end % of for k = 1:featurenum
    
    % build one big label vector
    Data.CV.vLabels = GetLabelVec(Data.CV.sPrimary);
    %labels=Data.CV.vLabels
    
    if findstr(Param.trialname,'_Diphone_')
        % eliminate frames with class 0
        Data.CV.vLabelsfull=Data.CV.vLabels;
        [Data.CV.vLabels,Data.CV.mSecondaryRefined]=EliminateZeroFrames(Data.CV.vLabelsfull,Data.CV.mSecondaryRefined);
    end
    
    Data.CV.target = maketarget(Data.CV.vLabels,Param.classnum); % Build target matrix 
        
    % Score net on cv data 
    Param.Dvec=ones(1,length(Data.CV.sPrimary))/length(Data.CV.sPrimary);
    %Dvec=Param.Dvec
    RMS = RMSerror(Test.net, Data.CV.mSecondaryRefined, Data.CV.target)
    [res,Ymod] = classify(Test.net, Data.CV.mSecondaryRefined, Data.CV.target, Param.Dvec);
    rate = res.rate;
    
    fprintf('TEST %s CV data\trate: %4.2f \t RMS: %6.4f \n',char(Param.Testdatatype(t)),res.rate*100,RMS)    
        
    disp('real / predicted ->')
    res.matrix
        
    % save file
    eval(['save testdir/' Param.trialname '-' char(Param.Testdatatype(t)) '.mat RMS res Ymod']);
        
end % of for t=[]

return

%%-----------------------------------------------------------------------------
%%
%%   Copyright (C) 2000-2004   
%%   Medizinische Physik,
%%   Universitaet Oldenburg, Germany
%%   All rights reserved. 
%%   http://www.physik.uni-oldenburg.de/docs/medi
%%
%%   Permission to use, copy, and distribute this software/file and its
%%   documentation for any purpose without permission by UNIVERSITAET OLDENBURG
%%   is not granted.
%%   
%%   Permission to use this software for purely research (excluding weapons 
%%   research) or educational purposes is granted, with the exception that 
%%   modified versions of the code may not be redistributed unless permission 
%%   has been obtained separately from UNIVERSITAET OLDENBURG.
%%
%%   Permission to use this software for weapons research or applications is 
%%   not granted.
%%
%%   No commercial exploitation of this software is permitted unless permission 
%%   has been obtained separately from UNIVERSITAET OLDENBURG. 
%%
%%   This software is provided "as is" without expressed or implied warranty.
%%
%%   Author:    Michael Kleinschmidt
%%   Co-Author: Bernd Meyer 
%%
%%   Please contact Bernd Meyer (bernd.meyer@uni-oldenburg.de) for 
%%   questions regarding this release.
%%----------------------------------------------------------------------------- 