function Test=train_sort(Param,Data,Test)

% function Test=train_sort(Param,Data,Test)
% function Test=train_sort(Param,Data)
%
% retraining and sorting of features
% recalcs features if not given as part of Data

if nargin == 2
    Test.sSelectSet=Param.Best.sSelectSet;
    Test.featurenum = Param.featurenum;
elseif nargin == 3 % calc features if necessary
    % Calc features
    fprintf('Calculate Feature # ')
    for k = 1:Test.featurenum
        
        fprintf('%i\n', k)
        
        % Calculate TRAIN Gabor feature 
        Data.Best.TRAIN.mSecondaryRefined(k, :) = FastCalcGaborMany(Data.TRAIN.sPrimary, Test.sSelectSet(k).prototype);
        
    end
    
    % build one big label vector
    Data.TRAIN.vLabels = GetLabelVec(Data.TRAIN.sPrimary);
    
    if findstr(Param.trialname,'_Diphone_')
        % eliminate frames with class 0
        Data.TRAIN.vLabelsfull=Data.TRAIN.vLabels;
        [Data.TRAIN.vLabels,Data.TRAIN.mSecondaryRefined]=EliminateZeroFrames(Data.TRAIN.vLabelsfull,Data.TRAIN.mSecondaryRefined);
        fprintf('keep %i out of %i frames (%4.2f percent)',length(Data.TRAIN.vLabels),length(Data.TRAIN.vLabelsfull),(length(Data.TRAIN.vLabels)/length(Data.TRAIN.vLabelsfull)*100));
    end
    
    disp(' prepare target')
    Data.Best.TRAIN.target = maketarget(Data.TRAIN.vLabels,Param.classnum); % Build target matrix 
    
    
else
    error('number of parameters incorrect!')    
end

if nargin == 2
    % train net 
    [Test.net,Test.psi] = trainer(Data.Best.TRAIN.mSecondaryRefined,Data.Best.TRAIN.target,Param);
    % Score net on train data 
    Test.TRAIN.D_RMS=RMSerror(Test.net, Data.Best.TRAIN.mSecondaryRefined,Data.Best.TRAIN.target,Param.Dvec);
    Test.TRAIN.RMS=RMSerror(Test.net, Data.Best.TRAIN.mSecondaryRefined,Data.Best.TRAIN.target);
else
    % train net 
    [Test.net,Test.psi] = trainer(Data.Best.TRAIN.mSecondaryRefined,Data.Best.TRAIN.target,Param);
    % Score net on train data 
    Test.TRAIN.RMS=RMSerror(Test.net, Data.Best.TRAIN.mSecondaryRefined,Data.Best.TRAIN.target);
end
[Test.TRAIN.res,Test.TRAIN.Ymod] = classify(Test.net,Data.Best.TRAIN.mSecondaryRefined,Data.Best.TRAIN.target,Param.Dvec);
Test.TRAIN.rate=Test.TRAIN.res.rate;

Test.Y = Data.Best.TRAIN.target;

% get relevance
[Test.relevance,error_without_ith_component] = evaluate(Test.net,Data.Best.TRAIN.mSecondaryRefined,Data.Best.TRAIN.target,Param,Param.Dvec);

% sort according to relevance
[Y,I]=sortrows(Test.relevance');

% rearrange features
for k=1:Test.featurenum
    Test.sSelectSetSort(k) = Test.sSelectSet(I(k));
end  

if Param.visual
    disp('real / predicted ->')
    Test.TRAIN.res.matrix
end

return

%%-----------------------------------------------------------------------------
%%
%%   Copyright (C) 2000-2004   
%%   Medizinische Physik,
%%   Universitaet Oldenburg, Germany
%%   All rights reserved. 
%%   http://www.physik.uni-oldenburg.de/docs/medi
%%
%%   Permission to use, copy, and distribute this software/file and its
%%   documentation for any purpose without permission by UNIVERSITAET OLDENBURG
%%   is not granted.
%%   
%%   Permission to use this software for purely research (excluding weapons 
%%   research) or educational purposes is granted, with the exception that 
%%   modified versions of the code may not be redistributed unless permission 
%%   has been obtained separately from UNIVERSITAET OLDENBURG.
%%
%%   Permission to use this software for weapons research or applications is 
%%   not granted.
%%
%%   No commercial exploitation of this software is permitted unless permission 
%%   has been obtained separately from UNIVERSITAET OLDENBURG. 
%%
%%   This software is provided "as is" without expressed or implied warranty.
%%
%%   Author:    Michael Kleinschmidt
%%   Co-Author: Bernd Meyer 
%%
%%   Please contact Bernd Meyer (bernd.meyer@uni-oldenburg.de) for 
%%   questions regarding this release.
%%----------------------------------------------------------------------------- 